==> ah-formbuilder-1.0.30.tgz: package/es/utils/predefined-values/NewOption.js <==
var _jsxFileName = "/home/mirza/code/formbuilder/src/utils/predefined-values/NewOption.js";
import React, { useEffect, useRef } from 'react';
import TextInput from "../inputs/TextInput";
import IconButton from "@material-ui/core/IconButton";
import DoneIcon from "@material-ui/icons/Done";
import { stringToSlug } from '../helpers';
import { Grid } from '@material-ui/core';
export default function NewOption(props) {
  var _React$useState = React.useState(''),
      name = _React$useState[0],
      setName = _React$useState[1];

  var _React$useState2 = React.useState(''),
      value = _React$useState2[0],
      setValue = _React$useState2[1];

  var _React$useState3 = React.useState(''),
      updated = _React$useState3[0],
      setUpdated = _React$useState3[1];

  var _React$useState4 = React.useState(''),
      error = _React$useState4[0],
      setError = _React$useState4[1];

  var inputRef = useRef();
  useEffect(function () {
    var _inputRef$current;

    inputRef == null ? void 0 : (_inputRef$current = inputRef.current) == null ? void 0 : _inputRef$current.focus();
  }, []);

  var handleNameChange = function handleNameChange(e) {
    setError('');
    setName(e.target.value);
  };

  var handleValueChange = function handleValueChange(e) {
    setError('');
    setValue(e.target.value);
  };

  var saveNewOption = function saveNewOption(e) {
    var _inputRef$current2;

    e.preventDefault();
    var values = [];
    var properValue = value;

    if (!value || value === '') {
      properValue = stringToSlug(name);
    }

    props.options.map(function (option) {
      var _option$name;

      values.push(option == null ? void 0 : (_option$name = option.name) == null ? void 0 : _option$name.toLowerCase());
    });

    if (values.includes(name == null ? void 0 : name.toLowerCase())) {
      setError('Category with same name already exists.');
    } else {
      props.saveNewCategoryOption(name, properValue);
      setName('');
      setValue('');
    }

    inputRef == null ? void 0 : (_inputRef$current2 = inputRef.current) == null ? void 0 : _inputRef$current2.focus();
  };

  return /*#__PURE__*/React.createElement("form", {
    onSubmit: saveNewOption,
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 49,
      columnNumber: 5
    }
  }, /*#__PURE__*/React.createElement(Grid, {
    container: true,
    className: "ahfb-pl-3",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 50,
      columnNumber: 7
    }
  }, /*#__PURE__*/React.createElement(Grid, {
    item: true,
    xs: 6,
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 51,
      columnNumber: 9
    }
  }, /*#__PURE__*/React.createElement(TextInput, {
    inputProps: {
      ref: inputRef
    },
    placeholder: "Name",
    value: name,
    handleChange: handleNameChange,
    error: error,
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 52,
      columnNumber: 11
    }
  })), /*#__PURE__*/React.createElement(Grid, {
    className: "ahfb-pl-2",
    item: true,
    xs: 6,
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 60,
      columnNumber: 9
    }
  }, /*#__PURE__*/React.createElement(TextInput, {
    placeholder: "Value",
    value: value,
    handleChange: handleValueChange,
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 61,
      columnNumber: 11
    }
  }))), /*#__PURE__*/React.createElement("button", {
    className: "ahfb-hidden",
    type: "submit",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 68,
      columnNumber: 7
    }
  }, "Submit"));
}

==> ah-formbuilder-1.0.61.tgz: package/es/utils/predefined-values/NewOption.js <==
import React, { useEffect, useRef } from 'react';
import TextInput from "../inputs/TextInput";
import IconButton from "@material-ui/core/IconButton";
import DoneIcon from "@material-ui/icons/Done";
import { stringToSlug } from '../helpers';
import { Grid } from '@material-ui/core';
export default function NewOption(props) {
  var _React$useState = React.useState(''),
      name = _React$useState[0],
      setName = _React$useState[1];

  var _React$useState2 = React.useState(''),
      value = _React$useState2[0],
      setValue = _React$useState2[1];

  var _React$useState3 = React.useState(''),
      updated = _React$useState3[0],
      setUpdated = _React$useState3[1];

  var _React$useState4 = React.useState(''),
      error = _React$useState4[0],
      setError = _React$useState4[1];

  var inputRef = useRef();
  useEffect(function () {
    var _inputRef$current;

    inputRef == null ? void 0 : (_inputRef$current = inputRef.current) == null ? void 0 : _inputRef$current.focus();
  }, []);

  var handleNameChange = function handleNameChange(e) {
    setError('');
    setName(e.target.value);
  };

  var handleValueChange = function handleValueChange(e) {
    setError('');
    setValue(e.target.value);
  };

  var saveNewOption = function saveNewOption(e) {
    var _inputRef$current2;

    e.preventDefault();
    var values = [];
    var properValue = value;

    if (!value || value === '') {
      properValue = stringToSlug(name);
    }

    props.options.map(function (option) {
      var _option$name;

      values.push(option == null ? void 0 : (_option$name = option.name) == null ? void 0 : _option$name.toLowerCase());
    });

    if (values.includes(name == null ? void 0 : name.toLowerCase())) {
      setError('Category with same name already exists.');
    } else {
      props.saveNewCategoryOption(name, properValue);
      setName('');
      setValue('');
    }

    inputRef == null ? void 0 : (_inputRef$current2 = inputRef.current) == null ? void 0 : _inputRef$current2.focus();
  };

  return /*#__PURE__*/React.createElement("form", {
    onSubmit: saveNewOption
  }, /*#__PURE__*/React.createElement(Grid, {
    container: true,
    className: "ahfb-pl-3"
  }, /*#__PURE__*/React.createElement(Grid, {
    item: true,
    xs: 6
  }, /*#__PURE__*/React.createElement(TextInput, {
    inputProps: {
      ref: inputRef
    },
    placeholder: "Name",
    value: name,
    handleChange: handleNameChange,
    error: error
  })), /*#__PURE__*/React.createElement(Grid, {
    className: "ahfb-pl-2",
    item: true,
    xs: 6
  }, /*#__PURE__*/React.createElement(TextInput, {
    placeholder: "Value",
    value: value,
    handleChange: handleValueChange
  }))), /*#__PURE__*/React.createElement("button", {
    className: "ahfb-hidden",
    type: "submit"
  }, "Submit"));
}
